@@ -1,25 +1,26 @@
 #!/usr/bin/env python
 
-'''
+"""
 Use the Python DTrace consumer as a Thread and run a syscall counter DTrace
 script.
 
 Created on Oct 10, 2011
 
 @author: tmetsch
-'''
+"""
 
-from dtrace import DTraceConsumerThread
 import time
 
+import dtrace
+
 SCRIPT = 'syscall:::entry { @num[execname] = count(); }'
 
 
 def main():
-    '''
+    """
     Run DTrace...
-    '''
-    thr = DTraceConsumerThread(SCRIPT)
+    """
+    thr = dtrace.DTraceConsumerThread(SCRIPT)
     thr.start()
 
     # we will stop the thread after some time...
@@ -29,5 +30,6 @@ def main():
     thr.stop()
     thr.join()
 
+
 if __name__ == '__main__':
     main()
